@@ -3,11 +3,8 @@ use strict;
 use warnings;
 
 package Perl::PrereqScanner;
-{
-  $Perl::PrereqScanner::VERSION = '1.018';
-}
 # ABSTRACT: a tool to scan your Perl code for its prerequisites
-
+$Perl::PrereqScanner::VERSION = '1.020';
 use Moose;
 
 use List::Util qw(max);
@@ -19,7 +16,7 @@ use String::RewritePrefix 0.005 rewrite => {
   prefixes => { '' => 'Perl::PrereqScanner::Scanner::', '=' => '' },
 };
 
-use CPAN::Meta::Requirements 2.120630; # normalized v-strings
+use CPAN::Meta::Requirements 2.124; # normalized v-strings
 
 use namespace::autoclean;
 
@@ -55,6 +52,20 @@ sub BUILD {
   $self->_set_scanners($scanners);
 }
 
+#pod =method scan_string
+#pod
+#pod   my $prereqs = $scanner->scan_string( $perl_code );
+#pod
+#pod Given a string containing Perl source code, this method returns a
+#pod CPAN::Meta::Requirements object describing the modules it requires.
+#pod
+#pod This method will throw an exception if PPI fails to parse the code.
+#pod
+#pod B<Warning!>  It isn't entirely clear whether PPI prefers to receive
+#pod strings as octet strings or character strings.  For now, my advice
+#pod is to pass octet strings.
+#pod
+#pod =cut
 
 sub scan_string {
   my ($self, $str) = @_;
@@ -64,6 +75,16 @@ sub scan_string {
   return $self->scan_ppi_document( $ppi );
 }
 
+#pod =method scan_file
+#pod
+#pod   my $prereqs = $scanner->scan_file( $path );
+#pod
+#pod Given a file path to a Perl document, this method returns a
+#pod CPAN::Meta::Requirements object describing the modules it requires.
+#pod
+#pod This method will throw an exception if PPI fails to parse the code.
+#pod
+#pod =cut
 
 sub scan_file {
   my ($self, $path) = @_;
@@ -74,6 +95,14 @@ sub scan_file {
   return $self->scan_ppi_document( $ppi );
 }
 
+#pod =method scan_ppi_document
+#pod
+#pod   my $prereqs = $scanner->scan_ppi_document( $ppi_doc );
+#pod
+#pod Given a L<PPI::Document>, this method returns a CPAN::Meta::Requirements object
+#pod describing the modules it requires.
+#pod
+#pod =cut
 
 sub scan_ppi_document {
   my ($self, $ppi_doc) = @_;
@@ -87,6 +116,15 @@ sub scan_ppi_document {
   return $req;
 }
 
+#pod =method scan_module
+#pod
+#pod   my $prereqs = $scanner->scan_module( $module_name );
+#pod
+#pod Given the name of a module, eg C<'PPI::Document'>,
+#pod this method returns a CPAN::Meta::Requirements object
+#pod describing the modules it requires.
+#pod
+#pod =cut
 
 sub scan_module {
   my ($self, $module_name) = @_;
@@ -102,17 +140,17 @@ sub scan_module {
 
 1;
 
-__END__
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Perl::PrereqScanner - a tool to scan your Perl code for its prerequisites
 
 =head1 VERSION
 
-version 1.018
+version 1.020
 
 =head1 SYNOPSIS
 
@@ -179,6 +217,10 @@ CPAN::Meta::Requirements object describing the modules it requires.
 
 This method will throw an exception if PPI fails to parse the code.
 
+B<Warning!>  It isn't entirely clear whether PPI prefers to receive
+strings as octet strings or character strings.  For now, my advice
+is to pass octet strings.
+
 =head2 scan_file
 
   my $prereqs = $scanner->scan_file( $path );
@@ -231,3 +273,58 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+#pod =for Pod::Coverage::TrustPod
+#pod   new
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod   use Perl::PrereqScanner;
+#pod   my $scanner = Perl::PrereqScanner->new;
+#pod   my $prereqs = $scanner->scan_ppi_document( $ppi_doc );
+#pod   my $prereqs = $scanner->scan_file( $file_path );
+#pod   my $prereqs = $scanner->scan_string( $perl_code );
+#pod   my $prereqs = $scanner->scan_module( $module_name );
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod The scanner will extract loosely your distribution prerequisites from your
+#pod files.
+#pod
+#pod The extraction may not be perfect but tries to do its best. It will currently
+#pod find the following prereqs:
+#pod
+#pod =begin :list
+#pod
+#pod * plain lines beginning with C<use> or C<require> in your perl modules and scripts, including minimum perl version
+#pod
+#pod * regular inheritance declared with the C<base> and C<parent> pragmata
+#pod
+#pod * L<Moose> inheritance declared with the C<extends> keyword
+#pod
+#pod * L<Moose> roles included with the C<with> keyword
+#pod
+#pod * OO namespace aliasing using the C<aliased> module
+#pod
+#pod =end :list
+#pod
+#pod =head2 Scanner Plugins
+#pod
+#pod Perl::PrereqScanner works by running a series of scanners over a PPI::Document
+#pod representing the code to scan.  By default the "Perl5", "Moose", "TestMore",
+#pod "POE", and "Aliased" scanners are run.  You can supply your own scanners when
+#pod constructing your PrereqScanner:
+#pod
+#pod   # Us only the Perl5 scanner:
+#pod   my $scanner = Perl::PrereqScanner->new({ scanners => [ qw(Perl5) ] });
+#pod
+#pod   # Use any stock scanners, plus Example:
+#pod   my $scanner = Perl::PrereqScanner->new({ extra_scanners => [ qw(Example) ] });
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod L<scan-perl-prereqs>, in this distribution, is a command-line interface to the scanner
+#pod
+#pod =cut
